import { x as Report, c as ConfigLoader, H as HtmlValidate, a as ConfigData } from './core.js';
export { A as AttributeData, a6 as AttributeEvent, f as CSSStyleDeclaration, aj as CompatibilityOptions, a8 as ConditionalEvent, C as Config, a as ConfigData, b as ConfigError, c as ConfigLoader, Z as ConfigReadyEvent, ab as DOMLoadEvent, ac as DOMReadyEvent, F as DeferredMessage, a9 as DirectiveEvent, aa as DoctypeEvent, D as DynamicValue, a5 as ElementReadyEvent, Y as Event, X as EventCallback, E as EventDump, V as EventHandler, af as FileSystemConfigLoader, ag as Formatter, e as HtmlElement, H as HtmlValidate, ae as ListenEventMap, L as Location, z as Message, l as MetaAttribute, m as MetaAttributeAllowedCallback, o as MetaCopyableProperty, M as MetaData, j as MetaDataTable, k as MetaElement, n as MetaTable, i as NestedError, N as NodeClosed, O as Parser, K as Plugin, P as ProcessElementContext, x as Report, y as Reporter, B as Result, R as Rule, s as RuleDocumentation, h as SchemaValidationError, S as Severity, w as Source, _ as SourceReadyEvent, d as StaticConfigLoader, a3 as TagCloseEvent, a2 as TagEndEvent, a1 as TagOpenEvent, a4 as TagReadyEvent, a0 as TagStartEvent, J as TemplateExtractor, u as TextClassification, T as TextNode, g as TokenDump, $ as TokenEvent, G as TransformContext, I as Transformer, ad as TriggerEventMap, U as UserError, a7 as WhitespaceEvent, W as WrappedError, t as classifyNodeText, ai as compatibilityCheck, p as configPresets, q as defineMetadata, ah as formatterFactory, r as metadataHelper, Q as ruleExists, v as version } from './core.js';
import 'ajv';

interface ExpandOptions {
    /**
     * Working directory. Defaults to `process.cwd()`.
     */
    cwd?: string;
    /**
     * List of extensions to search for when expanding directories. Extensions
     * should be passed without leading dot, e.g. "html" instead of ".html".
     */
    extensions?: string[];
}

interface InitResult {
    filename: string;
}

interface CLIOptions {
    configFile?: string;
    rules?: string | string[];
}
/**
 * @public
 */
declare class CLI {
    private options;
    private config;
    private loader;
    private ignored;
    /**
     * Create new CLI helper.
     *
     * Can be used to create tooling with similar properties to bundled CLI
     * script.
     */
    constructor(options?: CLIOptions);
    /**
     * Returns list of files matching patterns and are not ignored. Filenames will
     * have absolute paths.
     *
     * @public
     */
    expandFiles(patterns: string[], options?: ExpandOptions): string[];
    getFormatter(formatters: string): (report: Report) => string;
    /**
     * Initialize project with a new configuration.
     *
     * A new `.htmlvalidate.json` file will be placed in the path provided by
     * `cwd`.
     */
    init(cwd: string): Promise<InitResult>;
    /**
     * Searches ".htmlvalidateignore" files from filesystem and returns `true` if
     * one of them contains a pattern matching given filename.
     */
    isIgnored(filename: string): boolean;
    /**
     * Clear cache.
     *
     * Previously fetched [[HtmlValidate]] instances must either be fetched again
     * or call [[HtmlValidate.flushConfigCache]].
     */
    clearCache(): void;
    /**
     * Get HtmlValidate instance with configuration based on options passed to the
     * constructor.
     *
     * @internal
     */
    getLoader(): ConfigLoader;
    /**
     * Get HtmlValidate instance with configuration based on options passed to the
     * constructor.
     *
     * @public
     */
    getValidator(): HtmlValidate;
    /**
     * @internal
     */
    getConfig(): ConfigData;
}

export { CLI };
